<?xml version="1.0" encoding="iso-8859-1" ?>
<xsl:stylesheet
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:xsd="http://www.w3.org/2001/XMLSchema"
 xmlns:xyz="urn:appInfo:Items"
 version="1.0">

 <xsl:output encoding="windows-1252"/>

 <xsl:template match="text()"/>
 <xsl:template match="comment()"/>

 <xsl:template match="/xsd:schema">
  <html>
   <head>
    <title>Standard Values for XLIFF Attributes</title>
    <style>
&lt;!--
body { margin: 20; }
h1   { padding-top: 0in; color: #523184; }
h2   { color: #523184; margin-top: 35; padding-top: 10; border-top: solid 1px; }
h3   { color: #523184; margin-top: 30; }
h4   { color: #523184; }
h5   { color: #523184; }
pre  { background-color: #ffffee; padding: 10; border: solid 1px; whitespace: pre }
span.proposal { background-color: lime; }
span.note { background-color: yellow; }
table.attrvalues { border: 1; cellspacing: 0; cellpadding: 3; }
-->
    </style>
   </head>
   <body>
    <h1>Standard Values for XLIFF Attributes</h1>
    <p><xsl:value-of select="xsd:annotation/xsd:documentation"/></p>
    <xsl:apply-templates/>
    <p>-end-</p>
   </body>
  </html>
 </xsl:template>

 <xsl:template match="//xsd:simpleType">
  <h2><xsl:value-of select="@name"/></h2>
  <p><xsl:value-of select="xsd:annotation/xsd:documentation"/></p>
  <xsl:apply-templates/>
 </xsl:template>

 <xsl:template match="//xsd:union">
  <p>Union of the following types: <xsl:value-of select="@memberTypes"/></p>
  <xsl:apply-templates/>
 </xsl:template>

 <xsl:template match="//xsd:restriction">
#####BEGIN <xsl:value-of select="../@name"/><xsl:text>&#x0d;&#x0a;</xsl:text>
  <p class="item">The base type of the attribute value is <xsl:value-of select="@base"/>.
The pre-defined values are defined in the table below.
If user-defined values are used, they must start with a "x-" prefix.</p>
  <table class="attrvalues">
  <xsl:apply-templates/>
  </table>
#####END<xsl:text>&#x0d;&#x0a;</xsl:text>
 </xsl:template>

 <xsl:template match="//xsd:enumeration">
  <tr class="attrvalues">
   <xsl:variable name="Pval"><xsl:value-of select="xsd:annotation/xsd:appinfo/xyz:proposal"/></xsl:variable>
   <xsl:variable name="Nval"><xsl:value-of select="xsd:annotation/xsd:appinfo/xyz:note"/></xsl:variable>
   <td valign='top'><xsl:value-of select="@value"/></td>
   <td valign='top'>
    <xsl:if test="$Pval!=''">
     <span class="proposal">(Proposed only) <xsl:value-of select="$Pval"/></span>:
    </xsl:if>
    <xsl:value-of select="xsd:annotation/xsd:documentation"/>
    <xsl:if test="$Nval!=''">
     <span class="note"><br/>Note: <xsl:value-of select="$Nval"/></span>
    </xsl:if>
   </td>
  </tr>
 </xsl:template>

 <xsl:template match="//xsd:pattern">
  <xsl:variable name="Nval"><xsl:value-of select="../../xsd:annotation/xsd:appinfo/xyz:note"/></xsl:variable>
  <tr class="attrvalues">
   <td valign='top'>Pattern:</td>
   <td valign='top'>
    <xsl:value-of select="@value"/>
    <xsl:if test="$Nval!=''">
     <span class="note"><br/>Note: <xsl:value-of select="$Nval"/></span>
    </xsl:if>
   </td>
  </tr>
 </xsl:template>

</xsl:stylesheet>
